#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#.IDENTIFICATION  msql_dbi.pl
#.LANGUAGE	  Perl5 script
#
#.PURPOSE	  Database Interface to mSQL
#
#		  &dbi_connect( $user, $pswd, $server, $database );
#		  &dbi_dosql( "... SQL commands ...");
#		  %row = &dbi_nextrow;
#		  &dbi_disconnect;
#		  &dbi_rowcount( $rows );
#		  &dbi_dateformat( $format );
#
#.AUTHOR	  Bo Frese Rasmussen [ST-ECF]   <bfrasmus@eso.org>
#
#.VERSION	1.0	22/12-1994	Creation (Sybase)
#.VERSION	1.1	11/02-1995	mSQL port
#------------------------------------------------------------------------------	
package WDB_DatabaseInterface;
require	"Msql.pm";

#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#.PURPOSE	Connects to a database.
#
#.REMARKS	This function must be called before any of the other functions
#		in this package.
#		It logs in to the given database server and connects to a
#		database.
#
#.RETURNS	Dies on error !
#------------------------------------------------------------------------------
sub main'dbi_connect
{
    local(  $user, $pswd, $server, $database ) = @_;

    $dbproc = Msql->Connect( $server, $database )
        or die "Can't connect to server $server ...\n";
}

#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#.PURPOSE	Prepares and executes an SQL statement, with error check etc.
#
#.REMARKS	Dies on error !
#
#.RETURNS	Return value of &dbresults 
#------------------------------------------------------------------------------
sub main'dbi_dosql 
{
    local($sql) = @_;

    $sth = $dbproc->Query( $sql ) 
    	or die "Error executing SQL query : $sql\n<p>\n$Msql::db_errstr\n";
}
 
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#.PURPOSE	Defines the fieldnames to be returned from dbi_getnextrow
#
#.REMARKS	If this function is defined the query sendt to dbi_dosql
#		should not use the 
# 		  'select <col_name> <col_label>, <col2_name> <col2_label>, ...'
#		notation but rather the simple
#		  'select <col_name>, <col2_name>, ...'
#		notation and then call dbi_fieldnames with the names of the 
#		labels to use :
#		  &dbi_fieldnames( '<col_label>', '<col2_label>', ...);
#		dbi_getnextrow will then return an associative array with the
#		<col_label>'s as key.
#
#.RETURNS	nothing
#------------------------------------------------------------------------------
sub main'dbi_fieldnames
{
    @fields = @_;
}

#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#.PURPOSE	Gets the next row from a previous select (dbi_dosql).
#
#.REMARKS	After a dbi_dosql("select ... ") call, this function can be 
#		called repeatetly to retrieve all rows of the query.
#
#		Example :
#			&dbi_dosql("select * from mytab");
#			while( %row = &dbi_nextrow  ) {
#			    print $row{'columnname'};
#			    ...
#			}
#
#.RETURNS	An associative array (keyed on the column label) of formatted 
#		data, based on the datatype of the corresponding columns.
#------------------------------------------------------------------------------
sub main'dbi_nextrow
{
    @row = $sth->FetchRow or return undef;

    for( $cn=0; $cn <= $#row; $cn++ ) {
    	$r{$fields[$cn]} = $row[$cn];
    }

    return %r;
}

#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#.PURPOSE	Disconnects the current database connection
#
#.REMARKS	After this function is called there are no current database 
#		connection => no other function from this package can be 
#		called before a new dbi_connect call.
#
#.RETURNS	nothing.
#------------------------------------------------------------------------------
sub main'dbi_disconnect
{
    $dbproc->DESTROY;
}

#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#.PURPOSE	Sets the maximim number of rows returned from a query.
#
#.REMARKS	Causes SQL server to stop processing the query ( select, 
#		insert update, delete) after the specified number of rows 
#		are affected.
#		
#		PORTING NOTE: This function is added for efficiency only. 
#		When used with WDB it can safely be ignored ( leave an
#		empty function body : {} )
#
#.RETURNS	nothing.
#------------------------------------------------------------------------------
sub main'dbi_rowcount
{
	# NOP	- not implemented in mSQL perl interface ???
}

#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#.PURPOSE	Sets the default output format for dates.
#
#.REMARKS	Sets the order of the date parts month/day/year for entering
#		datetime data. Valid arguments are mdy, dmy, ymd, ydm, myd, dym.
#
#.RETURNS	nothing.
#------------------------------------------------------------------------------
sub main'dbi_dateformat
{
	# NOP	- not implemented in mSQL perl interface ???
}

1;
